@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2018 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2020 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -385,7 +385,7 @@ void CClient::AcceptLogin(CUser& User) {
     // (constructor set a different timeout and mode)
     SetTimeout(User.GetNoTrafficTimeout(), TMO_READ);
 
-    SetSockName("USR::" + m_pUser->GetUserName());
+    SetSockName("USR::" + m_pUser->GetUsername());
     SetEncoding(m_pUser->GetClientEncoding());
 
     if (!m_sNetwork.empty()) {
@@ -413,7 +413,7 @@ void CClient::AcceptLogin(CUser& User) {
             PutStatusNotice(t_f(
                 "If you want to choose another network, use /znc JumpNetwork "
                 "<network>, or connect to ZNC with username {1}/<network> "
-                "(instead of just {1})")(m_pUser->GetUserName()));
+                "(instead of just {1})")(m_pUser->GetUsername()));
         }
     } else {
         PutStatusNotice(
@@ -470,7 +470,7 @@ void CClient::PutIRC(const CString& sLine) {
 
 CString CClient::GetFullName() const {
     if (!m_pUser) return GetRemoteIP();
-    CString sFullName = m_pUser->GetUserName();
+    CString sFullName = m_pUser->GetUsername();
     if (!m_sIdentifier.empty()) sFullName += "@" + m_sIdentifier;
     if (m_pNetwork) sFullName += "/" + m_pNetwork->GetName();
     return sFullName;
@@ -1086,9 +1086,8 @@ bool CClient::OnJoinMessage(CJoinMessage& Message) {
 
 bool CClient::OnModeMessage(CModeMessage& Message) {
     CString sTarget = Message.GetTarget();
-    CString sModes = Message.GetModes();
 
-    if (m_pNetwork && m_pNetwork->IsChan(sTarget) && sModes.empty()) {
+    if (m_pNetwork && m_pNetwork->IsChan(sTarget) && !Message.HasModes()) {
         // If we are on that channel and already received a
         // /mode reply from the server, we can answer this
         // request ourself.
@@ -1235,6 +1234,8 @@ bool CClient::OnTextMessage(CTextMessage& Message) {
         }
 
         if (sTarget.TrimPrefix(m_pUser->GetStatusPrefix())) {
+            EchoMessage(Message);
+
             if (sTarget.Equals("status")) {
                 CString sMsg = Message.GetText();
                 UserCommand(sMsg);
