@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2016 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2020 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,9 +14,10 @@
  * limitations under the License.
  */
 
-#include "znctest.h"
 #include <gmock/gmock.h>
 
+#include "znctest.h"
+
 using testing::HasSubstr;
 
 namespace znc_inttest {
@@ -244,7 +245,8 @@ TEST_F(ZNCTest, AwayNotify) {
     client.Write("USER user/test x x :x");
     QByteArray cap_ls;
     client.ReadUntilAndGet(" LS :", cap_ls);
-    ASSERT_THAT(cap_ls.toStdString(), AllOf(HasSubstr("cap-notify"), Not(HasSubstr("away-notify"))));
+    ASSERT_THAT(cap_ls.toStdString(),
+                AllOf(HasSubstr("cap-notify"), Not(HasSubstr("away-notify"))));
     client.Write("CAP REQ :cap-notify");
     client.ReadUntil("ACK :cap-notify");
     client.Write("CAP END");
@@ -262,6 +264,9 @@ TEST_F(ZNCTest, AwayNotify) {
     client.ReadUntil(":x!y@z AWAY :reason");
     ircd.Close();
     client.ReadUntil("DEL :away-notify");
+    // This test often fails on macos due to ZNC process not finishing.
+    // No idea why. Let's try to shutdown it more explicitly...
+    client.Write("znc shutdown");
 }
 
 TEST_F(ZNCTest, JoinKey) {
@@ -284,5 +289,15 @@ TEST_F(ZNCTest, JoinKey) {
     ircd.ReadUntil("JOIN #znc secret");
 }
 
+TEST_F(ZNCTest, StatusEchoMessage) {
+    auto znc = Run();
+    auto ircd = ConnectIRCd();
+    auto client = LoginClient();
+    client.Write("CAP REQ :echo-message");
+    client.Write("PRIVMSG *status :blah");
+    client.ReadUntil(":nick!user@irc.znc.in PRIVMSG *status :blah");
+    client.ReadUntil(":*status!znc@znc.in PRIVMSG nick :Unknown command");
+}
+
 }  // namespace
 }  // namespace znc_inttest
